@@ -6,9 +6,9 @@ Type annotations for resource-groups service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_resource_groups.type_defs import CreateGroupInputRequestTypeDef
+    from mypy_boto3_resource_groups.type_defs import ResourceQueryTypeDef
 
-    data: CreateGroupInputRequestTypeDef = {...}
+    data: ResourceQueryTypeDef = {...}
     ```
 """
 import sys
@@ -32,280 +32,64 @@ else:
 
 
 __all__ = (
-    "CreateGroupInputRequestTypeDef",
-    "CreateGroupOutputTypeDef",
+    "ResourceQueryTypeDef",
+    "GroupTypeDef",
+    "ResponseMetadataTypeDef",
     "DeleteGroupInputRequestTypeDef",
-    "DeleteGroupOutputTypeDef",
     "FailedResourceTypeDef",
     "GetGroupConfigurationInputRequestTypeDef",
-    "GetGroupConfigurationOutputTypeDef",
     "GetGroupInputRequestTypeDef",
-    "GetGroupOutputTypeDef",
     "GetGroupQueryInputRequestTypeDef",
-    "GetGroupQueryOutputTypeDef",
     "GetTagsInputRequestTypeDef",
-    "GetTagsOutputTypeDef",
-    "GroupConfigurationItemTypeDef",
     "GroupConfigurationParameterTypeDef",
-    "GroupConfigurationTypeDef",
     "GroupFilterTypeDef",
     "GroupIdentifierTypeDef",
-    "GroupQueryTypeDef",
     "GroupResourcesInputRequestTypeDef",
+    "PendingResourceTypeDef",
+    "PaginatorConfigTypeDef",
+    "ResourceFilterTypeDef",
+    "ResourceIdentifierTypeDef",
+    "ResourceStatusTypeDef",
+    "QueryErrorTypeDef",
+    "TagInputRequestTypeDef",
+    "UngroupResourcesInputRequestTypeDef",
+    "UntagInputRequestTypeDef",
+    "UpdateGroupInputRequestTypeDef",
+    "GroupQueryTypeDef",
+    "SearchResourcesInputRequestTypeDef",
+    "UpdateGroupQueryInputRequestTypeDef",
+    "DeleteGroupOutputTypeDef",
+    "GetGroupOutputTypeDef",
+    "GetTagsOutputTypeDef",
+    "TagOutputTypeDef",
+    "UntagOutputTypeDef",
+    "UpdateGroupOutputTypeDef",
+    "GroupConfigurationItemTypeDef",
+    "ListGroupsInputRequestTypeDef",
+    "ListGroupsOutputTypeDef",
     "GroupResourcesOutputTypeDef",
-    "GroupTypeDef",
+    "UngroupResourcesOutputTypeDef",
+    "ListGroupsInputListGroupsPaginateTypeDef",
+    "SearchResourcesInputSearchResourcesPaginateTypeDef",
     "ListGroupResourcesInputListGroupResourcesPaginateTypeDef",
     "ListGroupResourcesInputRequestTypeDef",
     "ListGroupResourcesItemTypeDef",
-    "ListGroupResourcesOutputTypeDef",
-    "ListGroupsInputListGroupsPaginateTypeDef",
-    "ListGroupsInputRequestTypeDef",
-    "ListGroupsOutputTypeDef",
-    "PaginatorConfigTypeDef",
-    "PendingResourceTypeDef",
-    "PutGroupConfigurationInputRequestTypeDef",
-    "QueryErrorTypeDef",
-    "ResourceFilterTypeDef",
-    "ResourceIdentifierTypeDef",
-    "ResourceQueryTypeDef",
-    "ResourceStatusTypeDef",
-    "ResponseMetadataTypeDef",
-    "SearchResourcesInputRequestTypeDef",
-    "SearchResourcesInputSearchResourcesPaginateTypeDef",
     "SearchResourcesOutputTypeDef",
-    "TagInputRequestTypeDef",
-    "TagOutputTypeDef",
-    "UngroupResourcesInputRequestTypeDef",
-    "UngroupResourcesOutputTypeDef",
-    "UntagInputRequestTypeDef",
-    "UntagOutputTypeDef",
-    "UpdateGroupInputRequestTypeDef",
-    "UpdateGroupOutputTypeDef",
-    "UpdateGroupQueryInputRequestTypeDef",
-    "UpdateGroupQueryOutputTypeDef",
-)
-
-_RequiredCreateGroupInputRequestTypeDef = TypedDict(
-    "_RequiredCreateGroupInputRequestTypeDef",
-    {
-        "Name": str,
-    },
-)
-_OptionalCreateGroupInputRequestTypeDef = TypedDict(
-    "_OptionalCreateGroupInputRequestTypeDef",
-    {
-        "Description": str,
-        "ResourceQuery": "ResourceQueryTypeDef",
-        "Tags": Mapping[str, str],
-        "Configuration": Sequence["GroupConfigurationItemTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateGroupInputRequestTypeDef(
-    _RequiredCreateGroupInputRequestTypeDef, _OptionalCreateGroupInputRequestTypeDef
-):
-    pass
-
-
-CreateGroupOutputTypeDef = TypedDict(
-    "CreateGroupOutputTypeDef",
-    {
-        "Group": "GroupTypeDef",
-        "ResourceQuery": "ResourceQueryTypeDef",
-        "Tags": Dict[str, str],
-        "GroupConfiguration": "GroupConfigurationTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DeleteGroupInputRequestTypeDef = TypedDict(
-    "DeleteGroupInputRequestTypeDef",
-    {
-        "GroupName": str,
-        "Group": str,
-    },
-    total=False,
-)
-
-DeleteGroupOutputTypeDef = TypedDict(
-    "DeleteGroupOutputTypeDef",
-    {
-        "Group": "GroupTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-FailedResourceTypeDef = TypedDict(
-    "FailedResourceTypeDef",
-    {
-        "ResourceArn": str,
-        "ErrorMessage": str,
-        "ErrorCode": str,
-    },
-    total=False,
-)
-
-GetGroupConfigurationInputRequestTypeDef = TypedDict(
-    "GetGroupConfigurationInputRequestTypeDef",
-    {
-        "Group": str,
-    },
-    total=False,
-)
-
-GetGroupConfigurationOutputTypeDef = TypedDict(
-    "GetGroupConfigurationOutputTypeDef",
-    {
-        "GroupConfiguration": "GroupConfigurationTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-GetGroupInputRequestTypeDef = TypedDict(
-    "GetGroupInputRequestTypeDef",
-    {
-        "GroupName": str,
-        "Group": str,
-    },
-    total=False,
-)
-
-GetGroupOutputTypeDef = TypedDict(
-    "GetGroupOutputTypeDef",
-    {
-        "Group": "GroupTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-GetGroupQueryInputRequestTypeDef = TypedDict(
-    "GetGroupQueryInputRequestTypeDef",
-    {
-        "GroupName": str,
-        "Group": str,
-    },
-    total=False,
-)
-
-GetGroupQueryOutputTypeDef = TypedDict(
     "GetGroupQueryOutputTypeDef",
-    {
-        "GroupQuery": "GroupQueryTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-GetTagsInputRequestTypeDef = TypedDict(
-    "GetTagsInputRequestTypeDef",
-    {
-        "Arn": str,
-    },
-)
-
-GetTagsOutputTypeDef = TypedDict(
-    "GetTagsOutputTypeDef",
-    {
-        "Arn": str,
-        "Tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredGroupConfigurationItemTypeDef = TypedDict(
-    "_RequiredGroupConfigurationItemTypeDef",
-    {
-        "Type": str,
-    },
-)
-_OptionalGroupConfigurationItemTypeDef = TypedDict(
-    "_OptionalGroupConfigurationItemTypeDef",
-    {
-        "Parameters": Sequence["GroupConfigurationParameterTypeDef"],
-    },
-    total=False,
-)
-
-
-class GroupConfigurationItemTypeDef(
-    _RequiredGroupConfigurationItemTypeDef, _OptionalGroupConfigurationItemTypeDef
-):
-    pass
-
-
-_RequiredGroupConfigurationParameterTypeDef = TypedDict(
-    "_RequiredGroupConfigurationParameterTypeDef",
-    {
-        "Name": str,
-    },
-)
-_OptionalGroupConfigurationParameterTypeDef = TypedDict(
-    "_OptionalGroupConfigurationParameterTypeDef",
-    {
-        "Values": Sequence[str],
-    },
-    total=False,
-)
-
-
-class GroupConfigurationParameterTypeDef(
-    _RequiredGroupConfigurationParameterTypeDef, _OptionalGroupConfigurationParameterTypeDef
-):
-    pass
-
-
-GroupConfigurationTypeDef = TypedDict(
+    "UpdateGroupQueryOutputTypeDef",
+    "CreateGroupInputRequestTypeDef",
     "GroupConfigurationTypeDef",
-    {
-        "Configuration": List["GroupConfigurationItemTypeDef"],
-        "ProposedConfiguration": List["GroupConfigurationItemTypeDef"],
-        "Status": GroupConfigurationStatusType,
-        "FailureReason": str,
-    },
-    total=False,
+    "PutGroupConfigurationInputRequestTypeDef",
+    "ListGroupResourcesOutputTypeDef",
+    "CreateGroupOutputTypeDef",
+    "GetGroupConfigurationOutputTypeDef",
 )
 
-GroupFilterTypeDef = TypedDict(
-    "GroupFilterTypeDef",
+ResourceQueryTypeDef = TypedDict(
+    "ResourceQueryTypeDef",
     {
-        "Name": GroupFilterNameType,
-        "Values": Sequence[str],
-    },
-)
-
-GroupIdentifierTypeDef = TypedDict(
-    "GroupIdentifierTypeDef",
-    {
-        "GroupName": str,
-        "GroupArn": str,
-    },
-    total=False,
-)
-
-GroupQueryTypeDef = TypedDict(
-    "GroupQueryTypeDef",
-    {
-        "GroupName": str,
-        "ResourceQuery": "ResourceQueryTypeDef",
-    },
-)
-
-GroupResourcesInputRequestTypeDef = TypedDict(
-    "GroupResourcesInputRequestTypeDef",
-    {
-        "Group": str,
-        "ResourceArns": Sequence[str],
-    },
-)
-
-GroupResourcesOutputTypeDef = TypedDict(
-    "GroupResourcesOutputTypeDef",
-    {
-        "Succeeded": List[str],
-        "Failed": List["FailedResourceTypeDef"],
-        "Pending": List["PendingResourceTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "Type": QueryTypeType,
+        "Query": str,
     },
 )
 
@@ -329,88 +113,115 @@ class GroupTypeDef(_RequiredGroupTypeDef, _OptionalGroupTypeDef):
     pass
 
 
-ListGroupResourcesInputListGroupResourcesPaginateTypeDef = TypedDict(
-    "ListGroupResourcesInputListGroupResourcesPaginateTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
+    },
+)
+
+DeleteGroupInputRequestTypeDef = TypedDict(
+    "DeleteGroupInputRequestTypeDef",
     {
         "GroupName": str,
         "Group": str,
-        "Filters": Sequence["ResourceFilterTypeDef"],
-        "PaginationConfig": "PaginatorConfigTypeDef",
     },
     total=False,
 )
 
-ListGroupResourcesInputRequestTypeDef = TypedDict(
-    "ListGroupResourcesInputRequestTypeDef",
+FailedResourceTypeDef = TypedDict(
+    "FailedResourceTypeDef",
+    {
+        "ResourceArn": str,
+        "ErrorMessage": str,
+        "ErrorCode": str,
+    },
+    total=False,
+)
+
+GetGroupConfigurationInputRequestTypeDef = TypedDict(
+    "GetGroupConfigurationInputRequestTypeDef",
+    {
+        "Group": str,
+    },
+    total=False,
+)
+
+GetGroupInputRequestTypeDef = TypedDict(
+    "GetGroupInputRequestTypeDef",
     {
         "GroupName": str,
         "Group": str,
-        "Filters": Sequence["ResourceFilterTypeDef"],
-        "MaxResults": int,
-        "NextToken": str,
     },
     total=False,
 )
 
-ListGroupResourcesItemTypeDef = TypedDict(
-    "ListGroupResourcesItemTypeDef",
+GetGroupQueryInputRequestTypeDef = TypedDict(
+    "GetGroupQueryInputRequestTypeDef",
     {
-        "Identifier": "ResourceIdentifierTypeDef",
-        "Status": "ResourceStatusTypeDef",
+        "GroupName": str,
+        "Group": str,
     },
     total=False,
 )
 
-ListGroupResourcesOutputTypeDef = TypedDict(
-    "ListGroupResourcesOutputTypeDef",
+GetTagsInputRequestTypeDef = TypedDict(
+    "GetTagsInputRequestTypeDef",
     {
-        "Resources": List["ListGroupResourcesItemTypeDef"],
-        "ResourceIdentifiers": List["ResourceIdentifierTypeDef"],
-        "NextToken": str,
-        "QueryErrors": List["QueryErrorTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "Arn": str,
     },
 )
 
-ListGroupsInputListGroupsPaginateTypeDef = TypedDict(
-    "ListGroupsInputListGroupsPaginateTypeDef",
+_RequiredGroupConfigurationParameterTypeDef = TypedDict(
+    "_RequiredGroupConfigurationParameterTypeDef",
     {
-        "Filters": Sequence["GroupFilterTypeDef"],
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "Name": str,
+    },
+)
+_OptionalGroupConfigurationParameterTypeDef = TypedDict(
+    "_OptionalGroupConfigurationParameterTypeDef",
+    {
+        "Values": Sequence[str],
     },
     total=False,
 )
 
-ListGroupsInputRequestTypeDef = TypedDict(
-    "ListGroupsInputRequestTypeDef",
+
+class GroupConfigurationParameterTypeDef(
+    _RequiredGroupConfigurationParameterTypeDef, _OptionalGroupConfigurationParameterTypeDef
+):
+    pass
+
+
+GroupFilterTypeDef = TypedDict(
+    "GroupFilterTypeDef",
     {
-        "Filters": Sequence["GroupFilterTypeDef"],
-        "MaxResults": int,
-        "NextToken": str,
+        "Name": GroupFilterNameType,
+        "Values": Sequence[str],
+    },
+)
+
+GroupIdentifierTypeDef = TypedDict(
+    "GroupIdentifierTypeDef",
+    {
+        "GroupName": str,
+        "GroupArn": str,
     },
     total=False,
 )
 
-ListGroupsOutputTypeDef = TypedDict(
-    "ListGroupsOutputTypeDef",
+GroupResourcesInputRequestTypeDef = TypedDict(
+    "GroupResourcesInputRequestTypeDef",
     {
-        "GroupIdentifiers": List["GroupIdentifierTypeDef"],
-        "Groups": List["GroupTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "Group": str,
+        "ResourceArns": Sequence[str],
     },
 )
 
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
-    },
-    total=False,
-)
-
 PendingResourceTypeDef = TypedDict(
     "PendingResourceTypeDef",
     {
@@ -419,20 +230,12 @@ PendingResourceTypeDef = TypedDict(
     total=False,
 )
 
-PutGroupConfigurationInputRequestTypeDef = TypedDict(
-    "PutGroupConfigurationInputRequestTypeDef",
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
     {
-        "Group": str,
-        "Configuration": Sequence["GroupConfigurationItemTypeDef"],
-    },
-    total=False,
-)
-
-QueryErrorTypeDef = TypedDict(
-    "QueryErrorTypeDef",
-    {
-        "ErrorCode": QueryErrorCodeType,
-        "Message": str,
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
     total=False,
 )
@@ -454,14 +257,6 @@ ResourceIdentifierTypeDef = TypedDict(
     total=False,
 )
 
-ResourceQueryTypeDef = TypedDict(
-    "ResourceQueryTypeDef",
-    {
-        "Type": QueryTypeType,
-        "Query": str,
-    },
-)
-
 ResourceStatusTypeDef = TypedDict(
     "ResourceStatusTypeDef",
     {
@@ -470,21 +265,61 @@ ResourceStatusTypeDef = TypedDict(
     total=False,
 )
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
+QueryErrorTypeDef = TypedDict(
+    "QueryErrorTypeDef",
     {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
+        "ErrorCode": QueryErrorCodeType,
+        "Message": str,
+    },
+    total=False,
+)
+
+TagInputRequestTypeDef = TypedDict(
+    "TagInputRequestTypeDef",
+    {
+        "Arn": str,
+        "Tags": Mapping[str, str],
+    },
+)
+
+UngroupResourcesInputRequestTypeDef = TypedDict(
+    "UngroupResourcesInputRequestTypeDef",
+    {
+        "Group": str,
+        "ResourceArns": Sequence[str],
+    },
+)
+
+UntagInputRequestTypeDef = TypedDict(
+    "UntagInputRequestTypeDef",
+    {
+        "Arn": str,
+        "Keys": Sequence[str],
+    },
+)
+
+UpdateGroupInputRequestTypeDef = TypedDict(
+    "UpdateGroupInputRequestTypeDef",
+    {
+        "GroupName": str,
+        "Group": str,
+        "Description": str,
+    },
+    total=False,
+)
+
+GroupQueryTypeDef = TypedDict(
+    "GroupQueryTypeDef",
+    {
+        "GroupName": str,
+        "ResourceQuery": ResourceQueryTypeDef,
     },
 )
 
 _RequiredSearchResourcesInputRequestTypeDef = TypedDict(
     "_RequiredSearchResourcesInputRequestTypeDef",
     {
-        "ResourceQuery": "ResourceQueryTypeDef",
+        "ResourceQuery": ResourceQueryTypeDef,
     },
 )
 _OptionalSearchResourcesInputRequestTypeDef = TypedDict(
@@ -503,112 +338,10 @@ class SearchResourcesInputRequestTypeDef(
     pass
 
 
-_RequiredSearchResourcesInputSearchResourcesPaginateTypeDef = TypedDict(
-    "_RequiredSearchResourcesInputSearchResourcesPaginateTypeDef",
-    {
-        "ResourceQuery": "ResourceQueryTypeDef",
-    },
-)
-_OptionalSearchResourcesInputSearchResourcesPaginateTypeDef = TypedDict(
-    "_OptionalSearchResourcesInputSearchResourcesPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class SearchResourcesInputSearchResourcesPaginateTypeDef(
-    _RequiredSearchResourcesInputSearchResourcesPaginateTypeDef,
-    _OptionalSearchResourcesInputSearchResourcesPaginateTypeDef,
-):
-    pass
-
-
-SearchResourcesOutputTypeDef = TypedDict(
-    "SearchResourcesOutputTypeDef",
-    {
-        "ResourceIdentifiers": List["ResourceIdentifierTypeDef"],
-        "NextToken": str,
-        "QueryErrors": List["QueryErrorTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-TagInputRequestTypeDef = TypedDict(
-    "TagInputRequestTypeDef",
-    {
-        "Arn": str,
-        "Tags": Mapping[str, str],
-    },
-)
-
-TagOutputTypeDef = TypedDict(
-    "TagOutputTypeDef",
-    {
-        "Arn": str,
-        "Tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-UngroupResourcesInputRequestTypeDef = TypedDict(
-    "UngroupResourcesInputRequestTypeDef",
-    {
-        "Group": str,
-        "ResourceArns": Sequence[str],
-    },
-)
-
-UngroupResourcesOutputTypeDef = TypedDict(
-    "UngroupResourcesOutputTypeDef",
-    {
-        "Succeeded": List[str],
-        "Failed": List["FailedResourceTypeDef"],
-        "Pending": List["PendingResourceTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-UntagInputRequestTypeDef = TypedDict(
-    "UntagInputRequestTypeDef",
-    {
-        "Arn": str,
-        "Keys": Sequence[str],
-    },
-)
-
-UntagOutputTypeDef = TypedDict(
-    "UntagOutputTypeDef",
-    {
-        "Arn": str,
-        "Keys": List[str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-UpdateGroupInputRequestTypeDef = TypedDict(
-    "UpdateGroupInputRequestTypeDef",
-    {
-        "GroupName": str,
-        "Group": str,
-        "Description": str,
-    },
-    total=False,
-)
-
-UpdateGroupOutputTypeDef = TypedDict(
-    "UpdateGroupOutputTypeDef",
-    {
-        "Group": "GroupTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredUpdateGroupQueryInputRequestTypeDef = TypedDict(
     "_RequiredUpdateGroupQueryInputRequestTypeDef",
     {
-        "ResourceQuery": "ResourceQueryTypeDef",
+        "ResourceQuery": ResourceQueryTypeDef,
     },
 )
 _OptionalUpdateGroupQueryInputRequestTypeDef = TypedDict(
@@ -627,10 +360,277 @@ class UpdateGroupQueryInputRequestTypeDef(
     pass
 
 
+DeleteGroupOutputTypeDef = TypedDict(
+    "DeleteGroupOutputTypeDef",
+    {
+        "Group": GroupTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetGroupOutputTypeDef = TypedDict(
+    "GetGroupOutputTypeDef",
+    {
+        "Group": GroupTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetTagsOutputTypeDef = TypedDict(
+    "GetTagsOutputTypeDef",
+    {
+        "Arn": str,
+        "Tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+TagOutputTypeDef = TypedDict(
+    "TagOutputTypeDef",
+    {
+        "Arn": str,
+        "Tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UntagOutputTypeDef = TypedDict(
+    "UntagOutputTypeDef",
+    {
+        "Arn": str,
+        "Keys": List[str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateGroupOutputTypeDef = TypedDict(
+    "UpdateGroupOutputTypeDef",
+    {
+        "Group": GroupTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredGroupConfigurationItemTypeDef = TypedDict(
+    "_RequiredGroupConfigurationItemTypeDef",
+    {
+        "Type": str,
+    },
+)
+_OptionalGroupConfigurationItemTypeDef = TypedDict(
+    "_OptionalGroupConfigurationItemTypeDef",
+    {
+        "Parameters": Sequence[GroupConfigurationParameterTypeDef],
+    },
+    total=False,
+)
+
+
+class GroupConfigurationItemTypeDef(
+    _RequiredGroupConfigurationItemTypeDef, _OptionalGroupConfigurationItemTypeDef
+):
+    pass
+
+
+ListGroupsInputRequestTypeDef = TypedDict(
+    "ListGroupsInputRequestTypeDef",
+    {
+        "Filters": Sequence[GroupFilterTypeDef],
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListGroupsOutputTypeDef = TypedDict(
+    "ListGroupsOutputTypeDef",
+    {
+        "GroupIdentifiers": List[GroupIdentifierTypeDef],
+        "Groups": List[GroupTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GroupResourcesOutputTypeDef = TypedDict(
+    "GroupResourcesOutputTypeDef",
+    {
+        "Succeeded": List[str],
+        "Failed": List[FailedResourceTypeDef],
+        "Pending": List[PendingResourceTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UngroupResourcesOutputTypeDef = TypedDict(
+    "UngroupResourcesOutputTypeDef",
+    {
+        "Succeeded": List[str],
+        "Failed": List[FailedResourceTypeDef],
+        "Pending": List[PendingResourceTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListGroupsInputListGroupsPaginateTypeDef = TypedDict(
+    "ListGroupsInputListGroupsPaginateTypeDef",
+    {
+        "Filters": Sequence[GroupFilterTypeDef],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+_RequiredSearchResourcesInputSearchResourcesPaginateTypeDef = TypedDict(
+    "_RequiredSearchResourcesInputSearchResourcesPaginateTypeDef",
+    {
+        "ResourceQuery": ResourceQueryTypeDef,
+    },
+)
+_OptionalSearchResourcesInputSearchResourcesPaginateTypeDef = TypedDict(
+    "_OptionalSearchResourcesInputSearchResourcesPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class SearchResourcesInputSearchResourcesPaginateTypeDef(
+    _RequiredSearchResourcesInputSearchResourcesPaginateTypeDef,
+    _OptionalSearchResourcesInputSearchResourcesPaginateTypeDef,
+):
+    pass
+
+
+ListGroupResourcesInputListGroupResourcesPaginateTypeDef = TypedDict(
+    "ListGroupResourcesInputListGroupResourcesPaginateTypeDef",
+    {
+        "GroupName": str,
+        "Group": str,
+        "Filters": Sequence[ResourceFilterTypeDef],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ListGroupResourcesInputRequestTypeDef = TypedDict(
+    "ListGroupResourcesInputRequestTypeDef",
+    {
+        "GroupName": str,
+        "Group": str,
+        "Filters": Sequence[ResourceFilterTypeDef],
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListGroupResourcesItemTypeDef = TypedDict(
+    "ListGroupResourcesItemTypeDef",
+    {
+        "Identifier": ResourceIdentifierTypeDef,
+        "Status": ResourceStatusTypeDef,
+    },
+    total=False,
+)
+
+SearchResourcesOutputTypeDef = TypedDict(
+    "SearchResourcesOutputTypeDef",
+    {
+        "ResourceIdentifiers": List[ResourceIdentifierTypeDef],
+        "NextToken": str,
+        "QueryErrors": List[QueryErrorTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetGroupQueryOutputTypeDef = TypedDict(
+    "GetGroupQueryOutputTypeDef",
+    {
+        "GroupQuery": GroupQueryTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 UpdateGroupQueryOutputTypeDef = TypedDict(
     "UpdateGroupQueryOutputTypeDef",
     {
-        "GroupQuery": "GroupQueryTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "GroupQuery": GroupQueryTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredCreateGroupInputRequestTypeDef = TypedDict(
+    "_RequiredCreateGroupInputRequestTypeDef",
+    {
+        "Name": str,
+    },
+)
+_OptionalCreateGroupInputRequestTypeDef = TypedDict(
+    "_OptionalCreateGroupInputRequestTypeDef",
+    {
+        "Description": str,
+        "ResourceQuery": ResourceQueryTypeDef,
+        "Tags": Mapping[str, str],
+        "Configuration": Sequence[GroupConfigurationItemTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateGroupInputRequestTypeDef(
+    _RequiredCreateGroupInputRequestTypeDef, _OptionalCreateGroupInputRequestTypeDef
+):
+    pass
+
+
+GroupConfigurationTypeDef = TypedDict(
+    "GroupConfigurationTypeDef",
+    {
+        "Configuration": List[GroupConfigurationItemTypeDef],
+        "ProposedConfiguration": List[GroupConfigurationItemTypeDef],
+        "Status": GroupConfigurationStatusType,
+        "FailureReason": str,
+    },
+    total=False,
+)
+
+PutGroupConfigurationInputRequestTypeDef = TypedDict(
+    "PutGroupConfigurationInputRequestTypeDef",
+    {
+        "Group": str,
+        "Configuration": Sequence[GroupConfigurationItemTypeDef],
+    },
+    total=False,
+)
+
+ListGroupResourcesOutputTypeDef = TypedDict(
+    "ListGroupResourcesOutputTypeDef",
+    {
+        "Resources": List[ListGroupResourcesItemTypeDef],
+        "ResourceIdentifiers": List[ResourceIdentifierTypeDef],
+        "NextToken": str,
+        "QueryErrors": List[QueryErrorTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateGroupOutputTypeDef = TypedDict(
+    "CreateGroupOutputTypeDef",
+    {
+        "Group": GroupTypeDef,
+        "ResourceQuery": ResourceQueryTypeDef,
+        "Tags": Dict[str, str],
+        "GroupConfiguration": GroupConfigurationTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetGroupConfigurationOutputTypeDef = TypedDict(
+    "GetGroupConfigurationOutputTypeDef",
+    {
+        "GroupConfiguration": GroupConfigurationTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
